 /* +---------------------------------------------------------------- */
 /*                                                                   */
 /* Microsoft Windows                                                 */
 /*                                                                   */
 /* Copyright (c) Microsoft Corporation 1991-1999                     */
 /*                                                                   */
 /* File:        secext.cpy                                           */
 /*                                                                   */
 /* Contents:  Security function prototypes for functions not part of */
 /*            the SSPI interface. This file should not be directly   */
 /*            included - include security.cpy instead.               */
 /*                                                                   */
 /*                                                                   */
 /* History:     22 Dec 92   RichardW    Created                      */
 /*                                                                   */
 /* ----------------------------------------------------------------- */



 %dcl #_SECEXT_H__ char ext;
 %if #_SECEXT_H__ = '' %then %do;
 %#_SECEXT_H__ = 'Y';

 %dcl UNICODE char ext;

 /* Extended Name APIs for ADS */

 define ordinal EXTENDED_NAME_FORMAT
   (
    /* Examples for the following formats assume a fictitous company  */
    /* which hooks into the global X.500 and DNS name spaces as       */
    /* follows.                                                       */
    /*                                                                */
    /* Enterprise root domain in DNS is                               */
    /*                                                                */
    /*      widget.com                                                */
    /*                                                                */
    /* Enterprise root domain in X.500 (RFC 1779 format) is           */
    /*                                                                */
    /*      O=Widget, C=US                                            */
    /*                                                                */
    /* There exists the child domain                                  */
    /*                                                                */
    /*      engineering.widget.com                                    */
    /*                                                                */
    /* equivalent to                                                  */
    /*                                                                */
    /*      OU=Engineering, O=Widget, C=US                            */
    /*                                                                */
    /* There exists a container within the Engineering domain         */
    /*                                                                */
    /*      OU=Software, OU=Engineering, O=Widget, C=US               */
    /*                                                                */
    /* There exists the user                                          */
    /*                                                                */
    /*      CN=John Doe, OU=Software, OU=Engineering, O=Widget, C=US  */
    /*                                                                */
    /* And this user's downlevel (pre-ADS) user name is               */
    /*                                                                */
    /*      Engineering\JohnDoe                                       */

    /* unknown name type                                              */
    NameUnknown          value(0),

    /* CN=John Doe, OU=Software, OU=Engineering, O=Widget, C=US       */
    NameFullyQualifiedDN value(1),

    /* Engineering\JohnDoe                                            */
    NameSamCompatible    value(2),

    /* Probably "John Doe" but could be something else.  I.e. The     */
    /* display name is not necessarily the defining RDN.              */
    NameDisplay          value(3),


    /* String-ized GUID as returned by IIDFromString().               */
    /* e.g. {4fa050f0-f561-11cf-bdd9-00aa003a77b6}                    */
    NameUniqueId         value(6),

    /* engineering.widget.com/software/John Doe                       */
    NameCanonical        value(7),

    /* johndoe@engineering.com                                        */
    NameUserPrincipal    value(8),

    /* Same as NameCanonical except that rightmost '/' is             */
    /* replaced with '\n' - even in domain-only case.                 */
    /* e.g. engineering.widget.com/software\nJohn Doe                 */
    NameCanonicalEx      value(9),

    /* www/srv.engineering.com/engineering.com                        */
    NameServicePrincipal value(10),

    /* DNS domain name + SAM username                                 */
    /* eg: engineering.widget.com\JohnDoe                             */
    NameDnsDomain        value(12)
   ) prec (31);
 dcl PEXTENDED_NAME_FORMAT pointer;

 dcl GetUserNameExA
     entry (type EXTENDED_NAME_FORMAT,
            char(*) varz byaddr,
            type ULONG byaddr)
    returns (type BOOLEAN byvalue optional)
    SEC_ENTRY external('GetUserNameExA');
 dcl GetUserNameExW
     entry (type EXTENDED_NAME_FORMAT,
            WCHAR(*) varz byaddr,
            type ULONG byaddr)
     returns (type BOOLEAN byvalue optional)
     SEC_ENTRY external('GetUserNameExW');

 %dcl GetUserNameEx char ext;
 %if UNICODE ^= '' %then %do;
   %GetUserNameEx='GetUserNameExW';
 %end; %else %do;
   %GetUserNameEx='GetUserNameExA';
 %end;

 dcl GetComputerObjectNameA
     entry (type EXTENDED_NAME_FORMAT,
            char(*) varz byaddr,
            type ULONG byaddr)
     returns (type BOOLEAN byvalue optional)
     SEC_ENTRY external('GetComputerObjectNameA');
 dcl GetComputerObjectNameW
     entry (type EXTENDED_NAME_FORMAT,
            WCHAR(*) varz byaddr,
            type ULONG byaddr)
     returns (type BOOLEAN byvalue optional)
     SEC_ENTRY external('GetComputerObjectNameW');

 %dcl GetComputerObjectName char ext;
 %if UNICODE ^= '' %then %do;
   %GetComputerObjectName='GetComputerObjectNameW';
 %end; %else %do;
   %GetComputerObjectName='GetComputerObjectNameA';
 %end;

 dcl TranslateNameA
     entry (char(*) varz byaddr nonasgn,
            type EXTENDED_NAME_FORMAT,
            type EXTENDED_NAME_FORMAT,
            char(*) varz byaddr,
            type ULONG byaddr)
     returns (type BOOLEAN byvalue optional)
     SEC_ENTRY external('TranslateNameA');
 dcl TranslateNameW
     entry (WCHAR(*) varz byaddr nonasgn,
            type EXTENDED_NAME_FORMAT,
            type EXTENDED_NAME_FORMAT,
            WCHAR(*) varz byaddr,
            type ULONG byaddr)
     returns (type BOOLEAN byvalue optional)
     SEC_ENTRY external('TranslateNameW');

 %dcl TranslateName char ext;
 %if UNICODE ^= '' %then %do;
   %TranslateName='TranslateNameW';
 %end; %else %do;
   %TranslateName='TranslateNameA';
 %end;

 %end; /* __SECEXT_H__ */
